6.20   os16: exec(3) 

NOME

    execl, execle, execlp, execv, execvp - esecuzione di un file

SINTASSI

    #include <unistd.h>
    extern char **environ;
    int execl  (const char *<path>, const char *<arg>, ...);
    int execle (const char *<path>, const char *<arg>, ...);
    int execlp (const char *<path>, const char *<arg>, ...);
    int execv  (const char *<path>, char *const <argv[]>);
    int execvp (const char *<path>, char *const <argv[]>);

DESCRIZIONE

    Le funzioni exec...() rimpiazzano il processo chiamante con un altro
    processo, ottenuto dal caricamento di un file eseguibile in memoria. Tutte
    queste funzioni si avvalgono, direttamente o indirettamente di execve(2) [
    5.10].

    Il primo argomento delle funzioni descritte qui e` il percorso,
    rappresentato dalla stringa <path>, di un file da eseguire.

    Le funzioni execl...(), dopo il percorso del file eseguibile, richiedono
    l'indicazione di una quantita` variabile di argomenti, a cominciare da
    <arg>, costituiti da stringhe, tenendo conto che dopo l'ultimo di questi
    argomenti, occorre fornire il puntatore nullo, NULL, per chiarire che
    questi sono terminati. L'argomento corrispondente al parametro <arg> deve
    essere una stringa contenente il nome del file da avviare, mentre gli
    argomenti successivi sono gli argomenti da passare al programma stesso.

    Rispetto al gruppo di funzioni execl...(), la funzione <execle()>, dopo il
    puntatore nullo che conclude la sequenza di argomenti per il programma da
    avviare, si attende una sequenza di altre stringhe, anche questa conclusa
    da un ultimo e definitivo puntatore nullo. Questa ulteriore sequenza di
    stringhe va a costituire l'ambiente del processo da avviare, pertanto il
    contenuto di tali stringhe deve essere del tipo <nome>=<valore>.

    Le funzioni execv...() hanno come ultimo argomento il puntatore a un array
    di stringhe, dove <argv[0]> deve essere il nome del file da avviare, mentre
    da <argv[1]> in poi, si tratta degli argomenti da passare al programma.
    Anche in questo caso, per riconoscere l'ultimo elemento di questo array,
    gli si deve assegnare il puntatore nullo.

    Le funzioni <execlp()> e <execvp()>, se ricevono solo il nome del file da
    eseguire, senza altre indicazioni del percorso, cercano questo file tra i
    percorsi indicati nella variabile di ambiente <PATH>, ammesso che sia
    dichiarata per il processo in corso.

    Tutte le funzioni qui descritte, a eccezione di <execle()>, trasmettono al
    nuovo processo lo stesso ambiente (le stesse variabili di ambiente) del
    processo chiamante.

VALORE RESTITUITO

    Queste funzioni, se hanno successo nel loro compito, non possono restituire
    alcunche', dato che in quel momento, il processo chiamante viene rimpiazzato
    da quello del file che viene eseguito. Pertanto, queste funzioni possono
    restituire soltanto un valore che rappresenta un errore, ovvero -1,
    aggiornando anche la variabile <errno> di conseguenza.

ERRORI

    Valore
    di      Significato
    <errno>
    E2BIG   Ci sono troppi argomenti.

    ENOMEM  Memoria insufficiente.

    ENOENT  Il file richiesto non esiste.

    EACCES  Il file non puo` essere avviato per la mancanza dei permessi di
            acceso necessari.
    ENOEXEC Il file non puo` essere un file eseguibile, perche' non ne ha le
            caratteristiche.
    EIO     Errore di input-output.

FILE SORGENTI

    lib/unistd.h [13.17]

    lib/unistd/execl.c [13.17.9]

    lib/unistd/execle.c [13.17.10]

    lib/unistd/execlp.c [13.17.11]

    lib/unistd/execv.c [13.17.12]

    lib/unistd/execvp.c [13.17.14]

    lib/unistd/execve.c [13.17.13]

VEDERE ANCHE

    execve(2) [5.10], fork(2) [5.14], environ(7) [9.1].

